# Classeviva.py
[`Wrapper`](https://rapidapi.com/blog/api-glossary/api-wrapper/) dell'API di [`Classeviva`](https://web.spaggiari.eu/) - registro elettronico di [`Spaggiari`](https://web.spaggiari.eu/www/app/default/index.php) - per Python.

![image](https://github.com/user-attachments/assets/e4bd8149-b913-4513-9d9e-47c30bb7a33a)

# Documentazione
La [`documentazione italiana`](https://classeviva.readthedocs.io/it/stable/) si trova su ReadTheDocs.

# Contributi
Il codice sorgente può essere modificato su [`GitHub Dev`](https://github.dev) con l'[`editor della repository`](https://github.dev/Lioydiano/Classeviva); anche aprire delle [issue]([url](https://github.com/Lioydiano/Classeviva/issues)) può aiutare.

# Pacchetto
Il pacchetto può essere scaricato dal `PyPI` tramite `pip`, il progetto si trova [`qui`](https://pypi.org/project/Classeviva.py/).

# API REST
L'`API REST` si trova a [`web.spaggiari.eu/rest`](https://web.spaggiari.eu/rest/), la documentazione si trova [su `GitHub`](https://github.com/Lioydiano/Classeviva-Official-Endpoints).
